@@ -4,10 +4,12 @@
 Run a job from hdf5.
 """
 
+from argparse import ArgumentParser, Namespace
+
 from pyiron_base.jobs.job.wrapper import job_wrapper_function
 
 
-def register(parser):
+def register(parser: ArgumentParser):
     parser.add_argument(
         "-d",
         "--debug",
@@ -25,13 +27,20 @@ def register(parser):
         action="store_true",
         help="submit to queuing system on remote host",
     )
+    parser.add_argument(
+        "-c",
+        "--collect",
+        action="store_true",
+        help="only collect output of calculation",
+    )
 
 
-def main(args):
+def main(args: Namespace) -> None:
     job_wrapper_function(
         working_directory=args.project,
         job_id=args.job_id,
         file_path=args.file_path,
         debug=args.debug,
         submit_on_remote=args.submit,
+        collect=args.collect,
     )
