@@ -446,7 +446,7 @@ class JobCore(HasGroups):
 
     @property
     def files_to_compress(self) -> list:
-        return self._files_to_compress
+        return self._files_to_compress or self.files.list()
 
     @property
     def files_to_remove(self) -> list:
@@ -747,9 +747,7 @@ class JobCore(HasGroups):
             int: job ID of the job
         """
         if job_specifier is not None:
-            return self.project.get_job_id(
-                job_specifier
-            )  # , sub_job_name=self.project_hdf5.h5_path)
+            return self.project.get_job_id(job_specifier)
         where_dict = {
             "job": str(self._name),
             "project": str(self.project_hdf5.project_path),
@@ -876,6 +874,7 @@ class JobCore(HasGroups):
                 _copy_database_entry(
                     new_job_core=new_job_core,
                     job_copied_id=self.job_id,
+                    username=state.settings.login_user,
                 )
             else:
                 new_job_core.reset_job_id(job_id=None)
@@ -1158,12 +1157,10 @@ class JobCore(HasGroups):
         Args:
             files_to_compress (list):
         """
-        if files_to_compress is None and len(self._files_to_compress) != 0:
-            files_to_compress = self._files_to_compress
-        elif files_to_compress is None:
-            files_to_compress = self.files.list()
+        if files_to_compress is None:
+            files_to_compress = self.files_to_compress
         if files_to_remove is None:
-            files_to_remove = self._files_to_remove
+            files_to_remove = self.files_to_remove
         else:
             files_to_remove = []
         _job_compress(
