@@ -5,12 +5,16 @@
 Set of functions to interact with the queuing system directly from within pyiron - optimized for the Sun grid engine.
 """
 
-import pandas
 import time
+from concurrent.futures import Future
+from typing import List, Optional, Union
+
 import numpy as np
+import pandas
+
+from pyiron_base.jobs.job.extension.jobstatus import job_status_finished_lst
 from pyiron_base.state import state
 from pyiron_base.utils.instance import static_isinstance
-from pyiron_base.jobs.job.extension.jobstatus import job_status_finished_lst
 
 __author__ = "Jan Janssen"
 __copyright__ = (
@@ -27,8 +31,11 @@ QUEUE_SCRIPT_PREFIX = "pi_"
 
 
 def queue_table(
-    job_ids=None, working_directory_lst=None, project_only=True, full_table=False
-):
+    job_ids: Optional[List[int]] = None,
+    working_directory_lst: Optional[List[str]] = None,
+    project_only: bool = True,
+    full_table: bool = False,
+) -> pandas.DataFrame:
     """
     Display the queuing system table as pandas.Dataframe
 
@@ -72,17 +79,27 @@ def queue_table(
                     ]
                 ]
             else:
-                return df[
-                    [
-                        any([working_dir.startswith(p) for p in working_directory_lst])
-                        for working_dir in list(df.working_directory)
+                if len(df) > 0 and "working_directory" in df.columns:
+                    return df[
+                        [
+                            any(
+                                [
+                                    working_dir.startswith(p)
+                                    for p in working_directory_lst
+                                ]
+                            )
+                            for working_dir in list(df.working_directory)
+                        ]
                     ]
-                ]
+                else:
+                    return df
     else:
         return None
 
 
-def queue_check_job_is_waiting_or_running(item):
+def queue_check_job_is_waiting_or_running(
+    item: Union[int, "pyiron_base.jobs.job.generic.GenericJob"],
+) -> Union[bool, None]:
     """
     Check if a job is still listed in the queue system as either waiting or running.
 
@@ -102,7 +119,7 @@ def queue_check_job_is_waiting_or_running(item):
         return None
 
 
-def queue_info_by_job_id(job_id):
+def queue_info_by_job_id(job_id: int) -> dict:
     """
     Display the queuing system info of job by qstat | grep  shell command
     as dictionary
@@ -119,7 +136,7 @@ def queue_info_by_job_id(job_id):
         return None
 
 
-def queue_is_empty():
+def queue_is_empty() -> bool:
     """
     Check if the queue table is currently empty - no more jobs to wait for.
 
@@ -132,7 +149,9 @@ def queue_is_empty():
         return True
 
 
-def queue_delete_job(item):
+def queue_delete_job(
+    item: Union[int, "pyiron_base.jobs.job.generic.GenericJob"],
+) -> Union[str, None]:
     """
     Delete a job from the queuing system
 
@@ -149,7 +168,9 @@ def queue_delete_job(item):
         return None
 
 
-def queue_enable_reservation(item):
+def queue_enable_reservation(
+    item: Union[int, "pyiron_base.jobs.job.generic.GenericJob"],
+) -> Union[str, None]:
     """
     Enable a reservation for a particular job within the queuing system
 
@@ -171,7 +192,11 @@ def queue_enable_reservation(item):
         return None
 
 
-def wait_for_job(job, interval_in_s=5, max_iterations=100):
+def wait_for_job(
+    job: "pyiron_base.jobs.job.generic.GenericJob",
+    interval_in_s: int = 5,
+    max_iterations: int = 100,
+) -> None:
     """
     Sleep until the job is finished but maximum interval_in_s * max_iterations seconds.
 
@@ -195,7 +220,7 @@ def wait_for_job(job, interval_in_s=5, max_iterations=100):
                     state.queue_adapter.transfer_file_to_remote(
                         file=job.project_hdf5.file_name,
                         transfer_back=True,
-                        delete_remote=False,
+                        delete_file_on_remote=False,
                     )
                     status_hdf5 = job.project_hdf5["status"]
                     job.status.string = status_hdf5
@@ -219,7 +244,16 @@ def wait_for_job(job, interval_in_s=5, max_iterations=100):
                 if job.status.string in job_status_finished_lst:
                     finished = True
                     break
-                time.sleep(interval_in_s)
+                elif isinstance(job.server.future, Future):
+                    try:
+                        job.server.future.result(timeout=interval_in_s)
+                    except TimeoutError:
+                        pass
+                    else:
+                        finished = job.server.future.done()
+                        break
+                else:
+                    time.sleep(interval_in_s)
             if not finished:
                 raise ValueError(
                     "Maximum iterations reached, but the job was not finished."
@@ -227,13 +261,13 @@ def wait_for_job(job, interval_in_s=5, max_iterations=100):
 
 
 def wait_for_jobs(
-    project,
-    interval_in_s=5,
-    max_iterations=100,
-    recursive=True,
-    ignore_exceptions=False,
-    try_collecting=False,
-):
+    project: "pyiron_base.project.generic.Project",
+    interval_in_s: int = 5,
+    max_iterations: int = 100,
+    recursive: bool = True,
+    ignore_exceptions: bool = False,
+    try_collecting: bool = False,
+) -> None:
     """
     Wait for the calculation in the project to be finished
 
@@ -262,8 +296,11 @@ def wait_for_jobs(
 
 
 def update_from_remote(
-    project, recursive=True, ignore_exceptions=False, try_collecting=False
-):
+    project: "pyiron_base.project.generic.Project",
+    recursive: bool = True,
+    ignore_exceptions: bool = False,
+    try_collecting: bool = False,
+) -> None:
     """
     Update jobs from the remote server
 
@@ -321,7 +358,9 @@ def update_from_remote(
             return failed_jobs
 
 
-def retrieve_job(job, try_collecting=False):
+def retrieve_job(
+    job: "pyiron_base.jobs.job.generic.GenericJob", try_collecting: bool = False
+) -> None:
     """
     Retrieve a job from remote server and check if it has a "finished status".
     Optionally try to collect its output.
@@ -342,7 +381,9 @@ def retrieve_job(job, try_collecting=False):
         job.run()
 
 
-def validate_que_request(item):
+def validate_que_request(
+    item: Union[int, "pyiron_base.jobs.job.generic.GenericJob"],
+) -> int:
     """
     Internal function to convert the job_ID or hamiltonian to the queuing system ID.
 
