@@ -1210,6 +1210,7 @@ class GenericJob(JobCore, HasDict):
             "restart_file_dict": self._restart_file_dict,
             "exclude_nodes_hdf": self._exclude_nodes_hdf,
             "exclude_groups_hdf": self._exclude_groups_hdf,
+            "compress_by_default": self._compress_by_default,
         }
         data_dict["server"] = self._server.to_dict()
         self._executable_activate_mpi()
@@ -1219,10 +1220,10 @@ class GenericJob(JobCore, HasDict):
             data_dict["import_directory"] = self._import_directory
         if self._executor_type is not None:
             data_dict["executor_type"] = self._executor_type
-        if len(self._files_to_compress) > 0:
-            data_dict["files_to_compress"] = self._files_to_compress
+        if len(self.files_to_compress) > 0:
+            data_dict["files_to_compress"] = self.files_to_compress
         if len(self._files_to_remove) > 0:
-            data_dict["files_to_compress"] = self._files_to_remove
+            data_dict["files_to_remove"] = self._files_to_remove
         data_dict["HDF_VERSION"] = self.__version__
         return data_dict
 
@@ -1247,6 +1248,8 @@ class GenericJob(JobCore, HasDict):
             self._restart_file_dict = generic_dict["restart_file_dict"]
             self._exclude_nodes_hdf = generic_dict["exclude_nodes_hdf"]
             self._exclude_groups_hdf = generic_dict["exclude_groups_hdf"]
+            if "compress_by_default" in generic_dict:
+                self._compress_by_default = generic_dict["compress_by_default"]
         # Backwards compatbility
         if "restart_file_list" in input_dict.keys():
             self._restart_file_list = input_dict["restart_file_list"]
@@ -1680,14 +1683,14 @@ class GenericJob(JobCore, HasDict):
                 "No executor type defined - Please set self.executor_type."
             )
         elif (
-            self._executor_type == "executorlib.Executor"
+            self._executor_type == "executorlib.SingleNodeExecutor"
             and platform.system() == "Darwin"
         ):
             # The Mac firewall might prevent connections based on the network address - especially Github CI
             return import_class(self._executor_type)(
                 max_cores=max_workers, hostname_localhost=True
             )
-        elif self._executor_type == "executorlib.Executor":
+        elif self._executor_type == "executorlib.SingleNodeExecutor":
             # The executorlib Executor defines max_cores rather than max_workers
             return import_class(self._executor_type)(max_cores=max_workers)
         elif isinstance(self._executor_type, str):
