@@ -543,7 +543,8 @@ def run_job_with_runmode_queue(job: "pyiron_base.jobs.job.generic.GenericJob") -
         **job.server.additional_arguments,
     )
     if que_id is not None:
-        job.server.queue_id = que_id
+        with job.server.unlocked():
+            job.server.queue_id = que_id
         job.project_hdf5.write_dict(data_dict={"server": job.server.to_dict()})
         print("Queue system id: ", que_id)
     else:
@@ -1076,7 +1077,6 @@ def execute_job_with_calculate_function(
         job.set_input_to_read_only()
         if job_crashed:
             job.status.aborted = True
-            job._hdf5["status"] = job.status.string
         else:
             job.save_output(output_dict=parsed_output, shell_output=shell_output)
             if not job.convergence_check():
@@ -1085,6 +1085,8 @@ def execute_job_with_calculate_function(
                 if job._compress_by_default:
                     job.compress()
                 job.status.finished = True
+        job._hdf5["status"] = job.status.string
+        job.update_master()
 
 
 def _generate_flux_execute_string(
