@@ -10,12 +10,14 @@ import textwrap
 from functools import wraps
 from typing import Union
 
-from pyiron_base.storage.parameters import GenericParameters
-from pyiron_base.storage.datacontainer import DataContainer
+from pyiron_snippets.deprecate import deprecate
+
 from pyiron_base.interfaces.object import HasStorage
 from pyiron_base.jobs.job.core import _doc_str_job_core_args
-from pyiron_base.jobs.job.generic import GenericJob, _doc_str_generic_job_attr
 from pyiron_base.jobs.job.extension.jobstatus import job_status_finished_lst
+from pyiron_base.jobs.job.generic import GenericJob, _doc_str_generic_job_attr
+from pyiron_base.storage.datacontainer import DataContainer
+from pyiron_base.storage.parameters import GenericParameters
 
 __author__ = "Jan Janssen"
 __copyright__ = (
@@ -61,7 +63,7 @@ class GenericMaster(GenericJob):
         self._job_object_dict = {}
         self._child_id_func = None
         self._child_id_func_str = None
-        self._python_only_job = True
+        self._job_with_calculate_function = True
 
     @property
     def child_names(self):
@@ -143,6 +145,7 @@ class GenericMaster(GenericJob):
 
     @wraps(GenericJob.set_input_to_read_only)
     def set_input_to_read_only(self):
+        super().set_input_to_read_only()
         self._input.read_only = True
 
     def first_child_name(self):
@@ -310,6 +313,10 @@ class GenericMaster(GenericJob):
         """
         return len(self._job_name_lst)
 
+    @deprecate(
+        "Use job.output for results, job.files to access files; job.content to access HDF storage and "
+        "job.child_project to access children of master jobs."
+    )
     def __getitem__(self, item):
         """
         Get/ read data from the GenericMaster
@@ -460,7 +467,7 @@ class GenericMaster(GenericJob):
             if len(name_lst) > 1:
                 return self.project.inspect(child_id)["/".join(name_lst[1:])]
             else:
-                return self.project.load(child_id, convert_to_object=True)
+                return self.project.load(child_id)
         elif item_obj in self._job_name_lst:
             child = self._load_job_from_cache(job_name=item_obj)
             if len(name_lst) == 1:
