@@ -139,7 +139,6 @@ class ListMaster(GenericMaster):
         """
         if self.status.finished:
             return True
-        # self.status.busy = True
         self.submission_status.refresh()
         if not self.submission_status.finished:
             return False
@@ -150,7 +149,6 @@ class ListMaster(GenericMaster):
                     for child_id in self.child_ids
                 ]
             )
-            # status_set = set([job.get_status() for job in self.iter_jobs(convert_to_object=False)])
             if "finished" in status_set:
                 return len(status_set) == 1
             else:
@@ -218,7 +216,7 @@ class ListMaster(GenericMaster):
         Internal helper function the run if refresh function is called when the job status is 'refresh'. If the job was
         suspended previously, the job is going to be started again, to be continued.
         """
-        log_str = "{}, status: {}, finished: {} parallel master " "refresh".format(
+        log_str = "{}, status: {}, finished: {} parallel master refresh".format(
             self.job_info_str, self.status, self.is_finished()
         )
         self._logger.info(log_str)
