@@ -6,9 +6,9 @@ Jobclass to execute python scripts and jupyter notebooks
 """
 
 import os
-import shutil
+from typing import Optional
+
 from pyiron_base.jobs.job.generic import GenericJob
-from pyiron_base.storage.parameters import GenericParameters
 from pyiron_base.storage.datacontainer import DataContainer
 
 __author__ = "Jan Janssen"
@@ -203,7 +203,7 @@ class ScriptJob(GenericJob):
 
         .. attribute:: job_type
 
-            Job type object with all the available job types: ['ExampleJob', 'SerialMaster', 'ParallelMaster', 'ScriptJob',
+            Job type object with all the available job types: ['ExampleJob', 'ParallelMaster', 'ScriptJob',
                                                                'ListMaster']
 
         .. attribute:: script_path
@@ -219,9 +219,14 @@ class ScriptJob(GenericJob):
         self._script_path = None
         self.input = DataContainer(table_name="custom_dict")
         self._enable_mpi4py = False
+        # Set job_with_calculate_function flag to true to use run_static() to execute the python function generated by
+        # the job with its arguments job.get_calculate_function(**job.calculate_kwargs) without calling the old
+        # interface with write_input() and collect_output(). Finally, the output dictionary is stored in the HDF5 file
+        # using self.save_output(output_dict, shell_output)
+        self._job_with_calculate_function = True
 
     @property
-    def script_path(self):
+    def script_path(self) -> str:
         """
         Python script path
 
@@ -231,7 +236,7 @@ class ScriptJob(GenericJob):
         return self._script_path
 
     @script_path.setter
-    def script_path(self, path):
+    def script_path(self, path: str) -> None:
         """
         Python script path
 
@@ -239,7 +244,9 @@ class ScriptJob(GenericJob):
             path (str): relative or absolute path to the python script or a corresponding notebook
         """
         if isinstance(path, str):
-            self._script_path = self._get_abs_path(path)
+            self._script_path = os.path.normpath(
+                os.path.join(os.path.abspath(os.path.curdir), path)
+            )
             self.executable = self._executable_command(
                 working_directory=self.working_directory,
                 script_path=self._script_path,
@@ -253,86 +260,57 @@ class ScriptJob(GenericJob):
                 "path should be a string, but ", path, " is a ", type(path), " instead."
             )
 
-    def enable_mpi4py(self):
-        self._enable_mpi4py = True
+    def collect_logfiles(self) -> None:
+        """
+        Compatibility function - but no log files are being collected
+        """
+        pass
 
-    def disable_mpi4py(self):
+    def disable_mpi4py(self) -> None:
+        """
+        Disables the usage of mpi4py for parallel execution.
+        """
         self._enable_mpi4py = False
 
-    def validate_ready_to_run(self):
-        if self.script_path is None:
-            raise TypeError(
-                "ScriptJob.script_path expects a path but got None. Please provide a path before "
-                + "running."
-            )
+    def enable_mpi4py(self) -> None:
+        """
+        Enable the usage of mpi4py for parallel execution.
+        """
+        self._enable_mpi4py = True
 
-    def set_input_to_read_only(self):
+    def _from_dict(self, obj_dict: dict, version: Optional[str] = None) -> None:
         """
-        This function enforces read-only mode for the input classes, but it has to be implement in the individual
-        classes.
-        """
-        self.input.read_only = True
-
-    def to_hdf(self, hdf=None, group_name=None):
-        """
-        Store the ScriptJob in an HDF5 file
+        Load job attributes from a dictionary.
 
         Args:
-            hdf (ProjectHDFio): HDF5 group object - optional
-            group_name (str): HDF5 subgroup name - optional
+            obj_dict (dict): The dictionary containing the job attributes.
+            version (str): The version of the job object.
         """
-        super(ScriptJob, self).to_hdf(hdf=hdf, group_name=group_name)
-        with self.project_hdf5.open("input") as hdf5_input:
-            hdf5_input["path"] = self._script_path
-            hdf5_input["parallel"] = self._enable_mpi4py
-            self.input.to_hdf(hdf5_input)
+        super()._from_dict(obj_dict=obj_dict)
+        if "parallel" in obj_dict["input"].keys():
+            self._enable_mpi4py = obj_dict["input"]["parallel"]
+        path = obj_dict["input"]["path"]
+        if path is not None:
+            self.script_path = path
+        if "custom_dict" in obj_dict["input"].keys():
+            self.input.update(obj_dict["input"]["custom_dict"])
 
-    def from_hdf(self, hdf=None, group_name=None):
+    def get_input_parameter_dict(self) -> dict:
         """
-        Restore the ScriptJob from an HDF5 file
+        Get an hierarchical dictionary of input files. On the first level the dictionary is divided in file_to_create
+        and files_to_copy. Both are dictionaries use the file names as keys. In file_to_create the values are strings
+        which represent the content which is going to be written to the corresponding file. In files_to_copy the values
+        are the paths to the source files to be copied.
 
-        Args:
-            hdf (ProjectHDFio): HDF5 group object - optional
-            group_name (str): HDF5 subgroup name - optional
+        Returns:
+            dict: hierarchical dictionary of input files
         """
-        super(ScriptJob, self).from_hdf(hdf=hdf, group_name=group_name)
-        if "HDF_VERSION" in self.project_hdf5.list_nodes():
-            version = self.project_hdf5["HDF_VERSION"]
-        else:
-            version = "0.1.0"
-        if version == "0.1.0":
-            with self.project_hdf5.open("input") as hdf5_input:
-                try:
-                    self.script_path = hdf5_input["path"]
-                    gp = GenericParameters(table_name="custom_dict")
-                    gp.from_hdf(hdf5_input)
-                    for k in gp.keys():
-                        self.input[k] = gp[k]
-                except TypeError:
-                    pass
-        elif version == "0.2.0":
-            with self.project_hdf5.open("input") as hdf5_input:
-                if "parallel" in hdf5_input.list_nodes():
-                    self._enable_mpi4py = hdf5_input["parallel"]
-                try:
-                    self.script_path = hdf5_input["path"]
-                except TypeError:
-                    pass
-                self.input.from_hdf(hdf5_input)
-        else:
-            raise ValueError("Cannot handle hdf version: {}".format(version))
-
-    def write_input(self):
-        """
-        Copy the script to the working directory - only python scripts and jupyter notebooks are supported
-        """
-        super().write_input()
+        input_file_dict = super().get_input_parameter_dict()
         if self._script_path is not None:
-            file_name = os.path.basename(self._script_path)
-            shutil.copyfile(
-                src=self._script_path,
-                dst=os.path.join(self.working_directory, file_name),
-            )
+            files_to_copy_dict = {
+                os.path.basename(self._script_path): self._script_path
+            }
+            input_file_dict["files_to_copy"].update(files_to_copy_dict)
             self.executable = self._executable_command(
                 working_directory=self.working_directory,
                 script_path=self._script_path,
@@ -341,12 +319,27 @@ class ScriptJob(GenericJob):
             )
             if self._enable_mpi4py:
                 self.executable._mpi = True
+        return input_file_dict
 
-    def collect_output(self):
+    def run_if_lib(self) -> None:
         """
-        Collect output function updates the master ID entries for all the child jobs created by this script job, if the
-        child job is already assigned to an master job nothing happens - master IDs are not overwritten.
+        Compatibility function - but library run mode is not available
         """
+        raise NotImplementedError(
+            "Library run mode is not implemented for script jobs."
+        )
+
+    def run_static(self) -> None:
+        """
+        The run_static() function is called internally in pyiron to trigger the execution of the executable. This is
+        typically divided into three steps: (1) the generation of the calculate function and its inputs, (2) the
+        execution of this function and (3) storing the output of this function in the HDF5 file.
+
+        In future the execution of the calculate function might be transferred to a separate process, so the separation
+        in these three distinct steps is necessary to simplify the submission to an external executor.
+        """
+        super().run_static()
+        # Update masterid for all jobs created in the working directory of the script job
         for job in self.project.iter_jobs(recursive=False, convert_to_object=False):
             pr_job = self.project.open(
                 os.path.relpath(job.working_directory, self.project.path)
@@ -355,24 +348,58 @@ class ScriptJob(GenericJob):
                 if pr_job.db.get_item_by_id(subjob_id)["masterid"] is None:
                     pr_job.db.item_update({"masterid": str(job.job_id)}, subjob_id)
 
-    def run_if_lib(self):
-        """
-        Compatibility function - but library run mode is not available
-        """
-        raise NotImplementedError(
-            "Library run mode is not implemented for script jobs."
-        )
+    def save_output(
+        self, output_dict: Optional[dict] = None, shell_output: Optional[str] = None
+    ) -> None:
+        pass
 
-    def collect_logfiles(self):
+    def set_input_to_read_only(self) -> None:
         """
-        Compatibility function - but no log files are being collected
+        This function enforces read-only mode for the input classes, but it has to be implement in the individual
+        classes.
+        """
+        super().set_input_to_read_only()
+        self.input.read_only = True
+
+    def _to_dict(self) -> dict:
+        """
+        Convert the job object to a dictionary.
+
+        Returns:
+            dict: A dictionary representation of the job object.
+        """
+        job_dict = super()._to_dict()
+        job_dict["input/path"] = self._script_path
+        job_dict["input/parallel"] = self._enable_mpi4py
+        job_dict["input/custom_dict"] = self.input.to_builtin()
+        return job_dict
+
+    def validate_ready_to_run(self) -> None:
+        """
+        Validates if the job is ready to run by checking if the script path is provided.
+
+        Raises:
+            TypeError: If the script path is not provided (i.e., is None).
+        """
+        if self.script_path is None:
+            raise TypeError(
+                "ScriptJob.script_path expects a path but got None. Please provide a path before "
+                + "running."
+            )
+
+    def _executable_activate_mpi(self) -> None:
+        """
+        Internal helper function to switch the executable to MPI mode
         """
         pass
 
     @staticmethod
     def _executable_command(
-        working_directory, script_path, enable_mpi4py=False, cores=1
-    ):
+        working_directory: str,
+        script_path: str,
+        enable_mpi4py: bool = False,
+        cores: int = 1,
+    ) -> str:
         """
         internal function to generate the executable command to either use jupyter or python
 
@@ -398,23 +425,3 @@ class ScriptJob(GenericJob):
             return ["mpirun", "-np", str(cores), "python", path]
         else:
             raise ValueError("Filename not recognized: ", path)
-
-    def _executable_activate_mpi(self):
-        """
-        Internal helper function to switch the executable to MPI mode
-        """
-        pass
-
-    @staticmethod
-    def _get_abs_path(path):
-        """
-        internal function to convert absolute or relative paths to absolute paths, using os.path.normpath,
-        os.path.abspath and os.path.curdir
-
-        Args:
-           path (str): relative or absolute path
-
-        Returns:
-            str: absolute path
-        """
-        return os.path.normpath(os.path.join(os.path.abspath(os.path.curdir), path))
