@@ -9,9 +9,10 @@ your project for a list of everything you should cite.
 `Publications` is the way we work towards this goal.
 """
 
+from typing import Dict, List, Union
+
 import pandas
-from pyiron_base.interfaces.singleton import Singleton
-from typing import Dict, Union, List
+from pyiron_snippets.singleton import Singleton
 from typing_extensions import Literal
 
 __author__ = "Joerg Neugebauer, Jan Janssen"
@@ -98,7 +99,7 @@ class Publications(metaclass=Singleton):
             pandas.DataFrame|dict|str: Publication data.
         """
 
-        def get_bibtex(k, v):
+        def get_bibtex(k: str, v: str) -> str:
             total_keys = [
                 "title",
                 "journal",
@@ -128,7 +129,7 @@ class Publications(metaclass=Singleton):
             bibtex_str += "}\n"
             return bibtex_str
 
-        def get_apa(v):
+        def get_apa(v: dict) -> str:
             apa_str = " & ".join(v["author"])
             if "year" in v.keys():
                 apa_str += " (" + v["year"] + "). "
